Module cookie

Module cookie 

Available on crate feature cookies only.
HTTP cookie storage and request selection.

Jar stores cookies received through Set-Cookie response fields and selects the cookies that apply to later requests. Domain, path, security, and expiration checks follow the RFC 6265 storage and retrieval model. CookieStore can be implemented to provide another storage backend while keeping the same client integration.

Structs

Cookie
A parsed HTTP cookie.
Jar
A good default CookieStore implementation.

Enums

Cookies
Serialized Cookie field values selected for an outgoing request.

Traits

CookieStore
Thread-safe cookie storage used by crate::Client.
IntoCookie
Converts cookie-like values into an owned Cookie.
IntoCookieStore
Converts cookie stores into a shared CookieStore.