Cookie

Struct Cookie 

pub struct Cookie<'a>(/* private fields */);
Available on crate feature cookies only.
A parsed HTTP cookie.

Implementations

Source

impl<'a> Cookie<'a>

pub fn name(&self) -> &str

Returns the name of self.

pub fn value(&self) -> &str

Returns the value of self.

Does not strip surrounding quotes.

pub fn http_only(&self) -> bool

Returns whether this cookie was marked HttpOnly or not.

pub fn secure(&self) -> bool

Returns whether this cookie was marked Secure or not.

pub fn same_site_lax(&self) -> bool

Returns whether the SameSite attribute of this cookie is Lax.

pub fn same_site_strict(&self) -> bool

Returns whether the SameSite attribute of this cookie is Strict.

pub fn path(&self) -> Option<&str>

Returns the Path of the cookie if one was specified.

pub fn domain(&self) -> Option<&str>

Returns the Domain of the cookie if one was specified.

This does not consider whether the Domain is valid; validation is left to higher-level libraries, as needed. However, if the Domain starts with a leading ., the leading . is stripped.

pub fn max_age(&self) -> Option<Duration>

Returns the specified max-age of the cookie if it is non-negative and representable.

pub fn expires(&self) -> Option<SystemTime>

Returns the expiration date-time of the cookie if one was specified.

Session cookies return None.

pub fn into_owned(self) -> Cookie<'static>

Converts self into a Cookie with a static lifetime with as few allocations as possible.