pub struct Cookie<'a>(/* private fields */);Available on crate feature
cookies only.Expand description
A parsed HTTP cookie.
Implementations
Sourceimpl<'a> Cookie<'a>
impl<'a> Cookie<'a>
Sourcepub fn same_site_lax(&self) -> bool
pub fn same_site_lax(&self) -> bool
Returns whether the SameSite attribute of this cookie is Lax.
Sourcepub fn same_site_strict(&self) -> bool
pub fn same_site_strict(&self) -> bool
Returns whether the SameSite attribute of this cookie is Strict.
Sourcepub fn domain(&self) -> Option<&str>
pub fn domain(&self) -> Option<&str>
Returns the Domain of the cookie if one was specified.
This does not consider whether the Domain is valid; validation is left to higher-level
libraries, as needed. However, if the Domain starts with a leading ., the leading . is
stripped.
Sourcepub fn max_age(&self) -> Option<Duration>
pub fn max_age(&self) -> Option<Duration>
Returns the specified max-age of the cookie if it is non-negative and representable.
Sourcepub fn expires(&self) -> Option<SystemTime>
pub fn expires(&self) -> Option<SystemTime>
Returns the expiration date-time of the cookie if one was specified.
Session cookies return None.
Sourcepub fn into_owned(self) -> Cookie<'static>
pub fn into_owned(self) -> Cookie<'static>
Converts self into a Cookie with a static lifetime with as few allocations as possible.